CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_config.h Source File

CCL

ccl_config.h
Go to the documentation of this file.
1
3 #pragma once
4
14 typedef enum transfer_function_t
15 {
16 // If using an emulator for P_NL
17 ccl_emulator = 0,
18 ccl_none = 0,
19
20 ccl_fitting_function = 1,
21 ccl_eisenstein_hu = 1,
22
23 ccl_bbks = 2,
24
25 ccl_boltzmann = 3,
26 ccl_boltzmann_class = 3,
27
28 ccl_boltzmann_camb = 4
29 } transfer_function_t;
30
38 typedef enum matter_power_spectrum_t
39 {
40 ccl_linear = 0,
41
42 ccl_halofit = 1,
43 // more?
44 ccl_halo_model = 3
45 // even more kinds ...
46
47 } matter_power_spectrum_t;
48
56 typedef enum mass_function_t
57 {
58 ccl_tinker = 1,
59 ccl_tinker10 = 2,
60 ccl_watson = 3,
61 ccl_angulo = 4
62 } mass_function_t;
63
70 typedef struct ccl_configuration {
71 transfer_function_t transfer_function_method;
72 matter_power_spectrum_t matter_power_spectrum_method;
73 mass_function_t mass_function_method;
74 // TODO: Halo definition
75 } ccl_configuration;
76
83 extern const ccl_configuration default_config;
ccl_boltzmann_class
Definition: ccl_config.h:26
ccl_eisenstein_hu
Definition: ccl_config.h:21
ccl_configuration
Definition: ccl_config.h:70
ccl_boltzmann
Definition: ccl_config.h:25
ccl_bbks
Definition: ccl_config.h:23
ccl_linear
Definition: ccl_config.h:40
mass_function_t
mass_function_t
Definition: ccl_config.h:56
ccl_configuration::matter_power_spectrum_method
matter_power_spectrum_t matter_power_spectrum_method
Definition: ccl_config.h:72
ccl_tinker10
Definition: ccl_config.h:59
ccl_none
Definition: ccl_config.h:18
ccl_halofit
Definition: ccl_config.h:42
ccl_boltzmann_camb
Definition: ccl_config.h:28
transfer_function_t
transfer_function_t
Definition: ccl_config.h:14
ccl_configuration::transfer_function_method
transfer_function_t transfer_function_method
Definition: ccl_config.h:71
ccl_watson
Definition: ccl_config.h:60
matter_power_spectrum_t
matter_power_spectrum_t
Definition: ccl_config.h:38
ccl_fitting_function
Definition: ccl_config.h:20
ccl_tinker
Definition: ccl_config.h:58
ccl_configuration::mass_function_method
mass_function_t mass_function_method
Definition: ccl_config.h:73
default_config
const ccl_configuration default_config
Definition: ccl_core.c:17
ccl_halo_model
Definition: ccl_config.h:44
ccl_emulator
Definition: ccl_config.h:17
ccl_angulo
Definition: ccl_config.h:61
ccl_configuration
struct ccl_configuration ccl_configuration